#
# spec file for package maven-plugin-tools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-plugin-tools
Version:        3.9.0
Release:        1.3
Summary:        Maven Plugin Tools
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugin-tools/
Source0:        https://repo1.maven.org/maven2/org/apache/maven/plugin-tools/%{name}/%{version}/%{name}-%{version}-source-release.zip
Source1:        %{name}-build.tar.xz
Patch0:         0002-Remove-dependency-on-jtidy.patch
BuildRequires:  ant
BuildRequires:  atinject
BuildRequires:  bsh2
BuildRequires:  fdupes
BuildRequires:  httpcomponents-client
BuildRequires:  httpcomponents-core
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local >= 6
BuildRequires:  jsoup
BuildRequires:  maven-lib
BuildRequires:  maven-reporting-api
BuildRequires:  maven-resolver-api
BuildRequires:  maven-wagon-provider-api
BuildRequires:  modello >= 2.0.0
BuildRequires:  objectweb-asm
BuildRequires:  plexus-ant-factory
BuildRequires:  plexus-archiver
BuildRequires:  plexus-bsh-factory
BuildRequires:  plexus-classworlds
BuildRequires:  plexus-containers-component-annotations
BuildRequires:  plexus-languages
BuildRequires:  plexus-utils
BuildRequires:  plexus-velocity
BuildRequires:  qdox
BuildRequires:  sisu-inject
BuildRequires:  sisu-plexus
BuildRequires:  slf4j
BuildRequires:  unzip
BuildRequires:  velocity
BuildArch:      noarch

%description
The Maven Plugin Tools contains the necessary tools to be able to produce Maven
Plugins in a variety of languages.

%package -n maven-plugin-annotations
Summary:        Maven Plugin Java 5 Annotations
Group:          Development/Libraries/Java

%description -n maven-plugin-annotations
This package contains Java 5 annotations to use in Mojos.

%package annotations
Summary:        Maven Plugin Tool for Annotations
Group:          Development/Libraries/Java

%description annotations
This package provides Java 5 annotation tools for use with Apache Maven.

%package ant
Summary:        Maven Plugin Tool for Ant
Group:          Development/Libraries/Java

%description ant
Descriptor extractor for plugins written in Ant.

%package api
Summary:        Maven Plugin Tools APIs
Group:          Development/Libraries/Java

%description api
The Maven Plugin Tools API provides an API to extract information from
and generate documentation for Maven Plugins.

%package beanshell
Summary:        Maven Plugin Tool for Beanshell
Group:          Development/Libraries/Java

%description beanshell
Descriptor extractor for plugins written in Beanshell.

%package generators
Summary:        Maven Plugin Tools Generators
Group:          Development/Libraries/Java

%description generators
The Maven Plugin Tools Generators provides content generation
(documentation, help) from plugin descriptor.

%package java
Summary:        Maven Plugin Tool for Java
Group:          Development/Libraries/Java

%description java
Descriptor extractor for plugins written in Java.

%package model
Summary:        Maven Plugin Metadata Model
Group:          Development/Libraries/Java

%description model
The Maven Plugin Metadata Model provides an API to play with the Metadata
model.

%package -n maven-script-ant
Summary:        Maven Ant Mojo Support
Group:          Development/Libraries/Java

%description -n maven-script-ant
This package provides %{summary}, which write Maven plugins with
Ant scripts.

%package -n maven-script-beanshell
Summary:        Maven Beanshell Mojo Support
Group:          Development/Libraries/Java

%description -n maven-script-beanshell
This package provides %{summary}, which write Maven plugins with
Beanshell scripts.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java
Provides:       %{name}-javadocs = %{version}-%{release}
Obsoletes:      %{name}-javadocs < %{version}-%{release}

%description javadoc
API documentation for %{name}.

%prep
%setup -q -a1
%patch0 -p1

%pom_remove_plugin -r :maven-enforcer-plugin

%pom_xpath_inject "pom:project/pom:properties" "
    <project.build.sourceEncoding>UTF-8</project.build.sourceEncoding>
    <project.reporting.outputEncoding>UTF-8</project.reporting.outputEncoding>"

# Remove test dependencies because tests are skipped anyways.
%pom_xpath_remove "pom:dependency[pom:scope='test']"

%pom_remove_dep net.sf.jtidy:jtidy maven-plugin-tools-generators

%build
mkdir -p lib
build-jar-repository -s lib \
    ant \
    atinject \
    bsh2/bsh \
    httpcomponents/httpclient \
    httpcomponents/httpcore \
    jsoup/jsoup \
    maven/maven-artifact \
    maven/maven-core \
    maven/maven-model \
    maven/maven-plugin-api \
    maven/maven-settings \
    maven-reporting-api/maven-reporting-api \
    maven-resolver/maven-resolver-api \
    maven-wagon/provider-api \
    objectweb-asm/asm \
    objectweb-asm/asm-commons \
    objectweb-asm/asm-util \
    org.eclipse.sisu.inject \
    org.eclipse.sisu.plexus \
    plexus/ant-factory \
    plexus/archiver \
    plexus/bsh-factory \
    plexus-classworlds \
    plexus-containers/plexus-component-annotations \
    plexus-languages/plexus-java \
    plexus/utils \
    plexus-velocity/plexus-velocity \
    qdox \
    slf4j/api \
    velocity

%{ant} \
    -Dtest.skip=true \
    package javadoc

%install
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
for i in \
    maven-plugin-annotations \
    maven-plugin-tools-annotations \
    maven-plugin-tools-api \
    maven-plugin-tools-generators \
    maven-plugin-tools-java; do
  install -pm 0644 ${i}/target/${i}-%{version}.jar %{buildroot}%{_javadir}/%{name}/${i}.jar
  %{mvn_install_pom} ${i}/pom.xml %{buildroot}%{_mavenpomdir}/%{name}/${i}.pom
  %add_maven_depmap %{name}/${i}.pom %{name}/${i}.jar -f ${i}
  if [ -d ${i}/target/site/apidocs ]; then
    cp -r ${i}/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/${i}
  fi
done
for i in \
    maven-plugin-tools-ant \
    maven-plugin-tools-beanshell \
    maven-plugin-tools-model \
    maven-script-ant \
    maven-script-beanshell; do
  install -pm 0644 maven-script/${i}/target/${i}-%{version}.jar %{buildroot}%{_javadir}/%{name}/${i}.jar
  %{mvn_install_pom} maven-script/${i}/pom.xml %{buildroot}%{_mavenpomdir}/%{name}/${i}.pom
  %add_maven_depmap %{name}/${i}.pom %{name}/${i}.jar -f ${i}
  if [ -d maven-script/${i}/target/site/apidocs ]; then
    cp -r maven-script/${i}/target/site/apidocs %{buildroot}%{_javadocdir}/%{name}/${i}
  fi
done
%fdupes -s %{buildroot}%{_javadocdir}

%files -n maven-plugin-annotations -f .mfiles-maven-plugin-annotations

%files annotations -f .mfiles-maven-plugin-tools-annotations
%license LICENSE NOTICE

%files ant -f .mfiles-maven-plugin-tools-ant

%files api -f .mfiles-maven-plugin-tools-api
%license LICENSE NOTICE

%files beanshell -f .mfiles-maven-plugin-tools-beanshell

%files generators -f .mfiles-maven-plugin-tools-generators

%files java -f .mfiles-maven-plugin-tools-java

%files model -f .mfiles-maven-plugin-tools-model
%license LICENSE NOTICE

%files -n maven-script-ant -f .mfiles-maven-script-ant
%license LICENSE NOTICE

%files -n maven-script-beanshell -f .mfiles-maven-script-beanshell
%license LICENSE NOTICE

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE NOTICE

%changelog
* Fri Sep 22 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.9.0
- Changes of version 3.9.0
  * Bug
    + MPLUGIN-470: *-mojo.xml (in PluginXdocGenerator) is
    overwritten when multiple locales are defined
    + MPLUGIN-471: Generated table by PluginXdocGenerator does not
    contain default attributes
  * Improvement
    + MPLUGIN-469: Omit empty line in generated help goal output if
    plugin description is empty
    + MPLUGIN-472: Use Plexus I18N rather than fiddling with
  * Task
    + MPLUGIN-467: Remove reporting from maven-plugin-plugin: create
    maven-plugin-report-plugin
  * Dependency upgrade
    + MPLUGIN-468: Upgrade plugins and components (in ITs)
- Changes of version 3.8.2
  * Improvement
    + MPLUGIN-457: Use Resolver API, get rid of localRepository
  * Dependency upgrade
    + MPLUGIN-458: Bump httpcore from 4.4.15 to 4.4.16
    + MPLUGIN-459: Bump httpclient from 4.5.13 to 4.5.14
    + MPLUGIN-460: Bump antVersion from 1.10.12 to 1.10.13
    + MPLUGIN-461: Bump slf4jVersion from 1.7.5 to 1.7.36
    + MPLUGIN-462: Bump plexus-java from 1.1.1 to 1.1.2
    + MPLUGIN-463: Bump plexus-archiver from 4.6.1 to 4.6.3
    + MPLUGIN-464: Bump jsoup from 1.15.3 to 1.15.4
    + MPLUGIN-465: Bump asmVersion from 9.4 to 9.5
    + MPLUGIN-466: Bump assertj-core from 3.23.1 to 3.24.2
- Changes of version 3.8.1
  * Bug
    + MPLUGIN-443: Javadoc reference containing a link label with
    spaces are not detected
    + MPLUGIN-444: JavadocLinkGenerator.createLink: Support nested
    binary class names
    + MPLUGIN-446: ERROR during build of m-plugin-report-p and
    m-plugin-p: Dependencies in wrong scope
    + MPLUGIN-448: "Executes as an aggregator plugin" documentation:
    s/plugin/goal/
    + MPLUGIN-452: Maven scope warning should be logged at WARN
    level
    + MPLUGIN-453: Fix Temporary File Information Disclosure
    Vulnerability
  * New Feature
    + MPLUGIN-441: Support mojos using the new maven v4 api
  * Improvement
    + MPLUGIN-425: Plugin descriptor should contain the
    requiredJavaVersion/requiredMavenVersion
    + MPLUGIN-439: Execute annotation only supports standard
    lifecycle phases due to use of enum
    + MPLUGIN-440: Clarify deprecation of all extractors but the
    maven-plugin-tools-annotations
  * Dependency upgrade
    + MPLUGIN-447: Update to Maven Parent POM 39
    + MPLUGIN-454: Bump junit-bom from 5.9.1 to 5.9.2
    + MPLUGIN-455: Bump plexus-archiver from 4.5.0 to 4.6.1
- Changes of version 3.7.1
  * Bug
    + MPLUGIN-452: Maven scope warning should be logged at WARN
    level
- Changes of version 3.7.0
  * Bug
    + MPLUGIN-298: The plugin descriptor generated by
    plugin:descriptor does not consider @ see javadoc taglets
    + MPLUGIN-394: Report-Mojo doesn't respect input encoding
    + MPLUGIN-403: Generating site reports for plugin results in
    NoSuchMethodError
    + MPLUGIN-404: JDK Requirements in plugin-info.html: Consider
    property "maven.compiler.release"
    + MPLUGIN-420: Parameters documentation inheriting @ since from
    Mojo can be confusing
    + MPLUGIN-428: Don't emit warning for missing javadoc URL of
    primitives
    + MPLUGIN-429: Don't emit warning for missing javadoc URI if no
    javadoc sources are configured
    + MPLUGIN-438: Parameter description should be taken from
    annotated item
  * New Feature
    + MPLUGIN-9: Add link to javadoc in configuration description
    page for user defined types of Mojos.
    + MPLUGIN-396: Allow only @ Deprecated annotation without @
    deprecated javadoc tag
    + MPLUGIN-400: add system requirements history section
    + MPLUGIN-402: report: allow to generate usage section in
    plugin-info.html with true
    + MPLUGIN-419: Allow @ Parameter on setters methods
    + MPLUGIN-423: Extract plugin report into its own plugin
    + MPLUGIN-427: report: Expose generics information of Collection
    and Map types
  * Improvement
    + MPLUGIN-297: plugin-info.html should contain a better Usage
    section
    + MPLUGIN-390: Do not overwrite generate files with no content
    change
    + MPLUGIN-393: Upgrade to JUnit 5 and @ Inject annotations
    + MPLUGIN-398: Support for java 20 - ASM 9.4
    + MPLUGIN-405: Don't print empty Memory, Disk Space in System
    Requirements
    + MPLUGIN-408: simplification in helpmojo build
    + MPLUGIN-411: Get rid of plexus-compiler-manager from tests
    + MPLUGIN-412: Use Maven core artifacts in provided scope
    + MPLUGIN-417: report and descriptor goal need to evaluate
    Javadoc comments differently
    + MPLUGIN-433: Allow to reference aggregator javadoc from plugin
    report
  * Task
    + MPLUGIN-378: Detect legacy/javadoc Mojo definitions, warn to
    use Java 5 annotations
    + MPLUGIN-389: Update level to Java 8
    + MPLUGIN-391: Deprecate scripting support for mojos
    + MPLUGIN-406: Deprecate requirements parameter in report Mojo
    + MPLUGIN-407: Remove duplicate code from PluginReport
    + MPLUGIN-409: Prepare for Doxia (Sitetools) 2.0.0
    + MPLUGIN-430: Fix documentation for maven-plugin-report-plugin
    + MPLUGIN-431: Remove deprecated items from new
    maven-plugin-report-plugin
    + MPLUGIN-432: Improve site build
    + MPLUGIN-434: Improve dependency management
    + MPLUGIN-437: Plugin generator generation fails when the parent
    class comes from a different project
  * Dependency upgrade
    + MPLUGIN-395: Upgrade Maven Reporting API/Impl to 3.1.0
    + MPLUGIN-397: Upgrade Parent to 36
    + MPLUGIN-399: Upgrade project dependencies after JDK 1.8
    + MPLUGIN-413: Bump maven-parent from 36 to 37
    + MPLUGIN-415: Upgrade Maven Reporting API to 3.1.1/Maven
    Reporting Impl to 3.2.0
    + MPLUGIN-422: Upgrade plexus-utils to 3.5.0
- Changes of version 3.6.4
  * What's Changed
    + MPLUGIN-384: restore compatibility with Maven 3 ecosystem
    + MPLUGIN-387: Upgrade dependencies
- Changes of version 3.6.3
  * What's Changed
    + MPLUGIN-383: add prerequisites to plugin pom
    + MPLUGIN-382: exclude dependency in provided scope from plugin
    descriptor
    + Get rid of String.format use
    + Fix this logging as well
    + (doc) Simplify documentation
    + MPLUGIN-386: Exclude maven-archiver and maven-jxr from warning
- Changes of version 3.6.2
  * What's Changed
    + MPLUGIN-374: deprecate unused requiresReports flag
    + MPLUGIN-370: Check that Maven dependencies are provided scope
    + Update ITs
    + use shared gh action
    + MPLUGIN-375: deprecate unsupported Mojo descriptor items
    + Weed out ITs
    + MPLUGIN-377: Upgrade to maven 3.x and avoid using deprecated
    API
    + MPLUGIN-376: Drop legacy dependencies
    + use shared gh action - v1
    + fix wording in javadoc
- Changes of version 3.6.1
  * What's Changed
    + Add missing @OverRide and make methods static
    + MPLUGIN-355: Upgrade to JUnit 4.12
    + upgrade parent POM and other dependencies
    + deps: update plugins
    + MPLUGIN-359: upgrade Doxia Sitetools to 1.9.2 to remove
    dependency on Struts
    + MNGSITE-393: remove Maven 2 info
    + remove unneeded dependency
    + tighten the dependency tree
    + ignore .checkstyle
    + strict dependencies for maven-plugin-tools-annotations
    + (doc) added "help" goal; goal number corrected
    + MPLUGIN-368: Improve @execute(goal...) docs
    + MPLUGIN-367: Improve @execute(lifecycle...) docs
- Modified patches:
  * maven-plugin-plugin-bootstrap-resouces.patch
  * regenerate in cycle
  * 0004-Remove-dependency-on-jtidy.patch
  - > 0002-Remove-dependency-on-jtidy.patch
  * regenerate to changed context
- Removed patches:
  * 0001-Avoid-duplicate-MOJO-parameters.patch
  * 0002-Deal-with-nulls-from-getComment.patch
  * 0003-Port-to-plexus-utils-3.0.24.patch
    + not needed with this version
* Sun Sep  3 2023 Fridrich Strba <fstrba@suse.com>
- Download sources from https://repo1.maven.org
* Sun Sep  3 2023 Fridrich Strba <fstrba@suse.com>
- Fix build with javapackages-local 6.2.0
  * com.sun:tools is not resolved from system any more
* Mon Jul 24 2023 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * 0004-Remove-dependency-on-jtidy.patch
* Fri May  5 2023 Fridrich Strba <fstrba@suse.com>
- Add _multibuild to define 2nd spec file as additional flavor.
  Eliminates the need for source package links in OBS.
* Fri May 13 2022 Fridrich Strba <fstrba@suse.com>
- Fix build with modello 2.0.0
* Mon Mar  7 2022 Fridrich Strba <fstrba@suse.com>
- Do not force building with java-1_8_0-openjdk, since the package
  builds just fine with higher versions.
* Tue May 11 2021 Fridrich Strba <fstrba@suse.com>
- Do not build against the legacy guava20 package any more
* Mon Nov 25 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream 3.6.0
  * allow building with java > 1.8 too against objectweb-asm 7.2
  * maven-plugin-tools-javadoc component does not exist any more
  * Renamed the package of documentation to
    maven-plugin-tools-javadoc since there is no name clash any
    more and it allows smooth upgrade
- Removed patch:
  * fix-getPluginsAsMap.patch
    + fix is present in the updated sources
* Fri Mar 29 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-plugin-tools 3.5.1
- Generate and customize ant build files
- Do not build maven-plugin-plugin in this spec, since it has
  circular dependency on itself
